import yaml
from agentic_base.constants import CONFIG_PATH
from agentic_base.utils import load_class
from agentic_mcp import MCPRunner


def get_runner(config_path: str = CONFIG_PATH) -> "MCPRunner":
    with open(config_path) as f:
        yaml_config = yaml.safe_load(f)
        klass = load_class(yaml_config["module_path"])
        return klass.from_settings()  # type: ignore[no-any-return]



from typing import Generic, Literal

from agentic_base.evaluation.settings import (
    DenseRetrieverSettings,
    NomicProcessorSettings,
    QdrantVectorStoreSettings,
    RerankerSettings,
    VLLMEmbedderSettings,
)
from agentic_base.settings import FromConfigMixinSettings
from pydantic_settings import BaseSettings

from agentic_mcp.constants import TCEvidenceBuilder


class ServerSettings(BaseSettings):
    transport: Literal['stdio', 'http', 'sse', 'streamable-http']
    host: str
    port: int


class RunnerSettings(FromConfigMixinSettings):
    pass


class EvidenceBuilderSettings(FromConfigMixinSettings):
    pass


class RetrieverWrapperSettings(BaseSettings):
    engine: DenseRetrieverSettings[
        VLLMEmbedderSettings, QdrantVectorStoreSettings, NomicProcessorSettings, RerankerSettings
    ]
    limit: int


class MCPRunnerSettings(RunnerSettings, Generic[TCEvidenceBuilder]):
    server: ServerSettings
    retriever: RetrieverWrapperSettings
    evidence: TCEvidenceBuilder
